@@ -1,41 +1,37 @@
+import json
 import logging
 import os
 import re
 from tempfile import NamedTemporaryFile
+
 from appdirs import user_config_dir
-import json
 
 try:
     from qgrid import show_grid
 except:
     pass
 
+from time import sleep
+
 import pandas as pd
 from pandas import DataFrame
 
 import sensiml.base.utility as utility
+from sensiml.base.snippets import Snippets, function_help
+from sensiml.connection import Connection
 from sensiml.datamanager import (
-    Functions,
-    PlatformDescriptions,
     ClientPlatformDescriptions,
-    PipelineSeeds,
+    Functions,
     Projects,
     SegmenterSet,
     Team,
 )
-from sensiml.datamanager.knowledgepack import (
-    get_knowledgepack,
-    get_knowledgepacks,
-    delete_knowledgepack,
-)
+from sensiml.datamanager.captures import CaptureExistsError
+from sensiml.datamanager.knowledgepack import delete_knowledgepack, get_knowledgepack
 from sensiml.datasets import DataSets
-from sensiml.connection import Connection
 
 # from sensiml.base.exceptions import *
 from sensiml.pipeline import Pipeline
-from sensiml.base.snippets import Snippets, function_help
-from sensiml.datamanager.captures import CaptureExistsError
-from time import sleep
 
 config_dir = user_config_dir(__name__.split(".")[0], False)
 
@@ -95,9 +91,7 @@ def print_list(func):
     return wrapper
 
 
-class SensiML(object):
-    """Entrance to SensiML Analytics Toolkit"""
-
+class Client(object):
     # Server Minimum Version For Compatibility
     __minversion__ = "2019.1.0"
 
@@ -121,14 +115,12 @@ class SensiML(object):
         self.projects = Projects(self._connection)
         self.datasets = DataSets()
         self.functions = Functions(self._connection)
-        self.platforms = PlatformDescriptions(self._connection)
         self.platforms_v2 = ClientPlatformDescriptions(self._connection)
-        self.seeds = PipelineSeeds(self._connection)
+        self.platforms = self.platforms_v2
         self.team = Team(self._connection)
         self.snippets = Snippets(
             self.list_functions(kp_functions=False, qgrid=False),
             self.functions.function_list,
-            self.seeds,
         )
         self._feature_files = None
 
@@ -275,35 +267,6 @@ class SensiML(object):
 
         return segmenters.to_dataframe()
 
-    def list_seeds(self):
-        """Lists all of the pipeline seeds on SensiML Cloud
-
-        Returns:
-            DataFrame: pipeline seeds on SensiML Cloud
-        """
-        return DataFrame(
-            {
-                "Name": [s.name for s in self.seeds],
-                "Description": [s.description for s in self.seeds],
-            }
-        )
-
-    def get_automl_parameter_inventory(self):
-        """
-        inventory parameters for AutoML
-
-        Returns:
-            DataFrame: AutoML parameter inventory
-        """
-
-        url = "automl/inventory/"
-
-        response = self._connection.request("get", url)
-
-        response_data, err = utility.check_server_response(response)
-
-        return DataFrame(response_data)
-
     def get_knowledgepack(self, uuid):
         """retrieve knowledgepack by uuid from the server associated with current project
 
