@@ -1,29 +1,24 @@
 import json
+import logging
 import os
-import sys
 import re
+import sys
+import urllib
+import warnings
+from time import sleep
 from uuid import UUID
 
-
-from pandas import DataFrame
-import json
-
-from numpy import int64
-import urllib
-import logging
-from time import sleep
-import warnings
-
 import sensiml.base.utility as utility
+from numpy import int64
+from pandas import DataFrame
+from sensiml.datamanager.clientplatformdescription import ClientPlatformDescription
 from sensiml.datamanager.confusion_matrix import (
     ConfusionMatrix,
     ConfusionMatrixException,
 )
 from sensiml.datamanager.deviceconfig import DeviceConfig
-from sensiml.datamanager.platformdescription import PlatformDescription
-from sensiml.datamanager.clientplatformdescription import ClientPlatformDescription
-from sensiml.visualize.knowledgepack_visualize_mixin import VisualizeMixin
 from sensiml.datamanager.featurefile import FeatureFile
+from sensiml.visualize.knowledgepack_visualize_mixin import VisualizeMixin
 
 logger = logging.getLogger(__name__)
 
@@ -223,11 +218,15 @@ class KnowledgePack(VisualizeMixin):
         """A JSON report of the Knowledge Pack cost summary"""
         return self.get_report("json")
 
-    def cost_resource_summary(self, processor_uuid=None):
+    def cost_resource_summary(self, processor_uuid=None, hardware_accelerator=None):
         """A summary of resources and time needed in a classification from a Knowledge Pack"""
-        return self.get_report("resource_summary", processor_uuid)
+        return self.get_report(
+            "resource_summary",
+            processor_uuid=processor_uuid,
+            hardware_accelerator=hardware_accelerator,
+        )
 
-    def get_report(self, report_type, processor_uuid=None):
+    def get_report(self, report_type, processor_uuid=None, hardware_accelerator=None):
         """Sends a request for a report to the server and returns the result.
 
         Args:
@@ -252,16 +251,18 @@ class KnowledgePack(VisualizeMixin):
             )
             return response.json()
         elif report_type == "resource_summary":
-            if processor_uuid is None:
-                url = "project/{0}/knowledgepack/{1}/report/{2}/".format(
-                    self._project_uuid, self.uuid, report_type
-                )
-            else:
-                url = "project/{0}/knowledgepack/{1}/report/{2}/{3}".format(
-                    self._project_uuid, self.uuid, report_type, processor_uuid
-                )
+            params = {}
+            if processor_uuid:
+                params["processor_uuid"] = processor_uuid
+            if hardware_accelerator:
+                params["accelerator"] = hardware_accelerator
+
+            url = "project/{0}/knowledgepack/{1}/report/{2}/".format(
+                self._project_uuid, self.uuid, report_type
+            )
+
             response = self._connection.request(
-                "get", url, headers={"Accept": "application/json"}
+                "get", url, params=params, headers={"Accept": "application/json"}
             )
             return response.json()
 
@@ -543,65 +544,17 @@ class KnowledgePack(VisualizeMixin):
     def download_library(
         self, folder="", run_async=True, platform=None, renderer=None, *args, **kwargs
     ):
-        """Calls the server to generate static library image based on device config.
-
-        Args:
-            folder (str): Folder to save to if not generating a link
-
-        Returns:
-            str: Denoting success, or link to file download
-        """
-        return self._download(
-            folder=folder,
-            bin_or_lib="lib",
-            run_async=run_async,
-            platform=platform,
-            renderer=renderer,
-            *args,
-            **kwargs
-        )
+        print("this API was removed. use download_library_v2")
 
     def download_source(
         self, folder="", run_async=True, platform=None, renderer=None, *args, **kwargs
     ):
-        """Calls the server to generate static library image based on device config.
-
-        Args:
-            folder (str): Folder to save to if not generating a link
-
-        Returns:
-            str: Denoting success, or link to file download
-        """
-        return self._download(
-            folder=folder,
-            bin_or_lib="source",
-            run_async=run_async,
-            platform=platform,
-            renderer=renderer,
-            *args,
-            **kwargs
-        )
+        print("this API was removed. use download_source_v2")
 
     def download_binary(
         self, folder="", run_async=True, platform=None, renderer=None, *args, **kwargs
     ):
-        """Calls the server to generate full binary image based on device config.
-
-        Args:
-            folder (str): Folder to save to if not generating a link
-
-        Returns:
-            str: Denoting success, or link to file download
-        """
-        return self._download(
-            folder=folder,
-            bin_or_lib="bin",
-            run_async=run_async,
-            platform=platform,
-            renderer=renderer,
-            *args,
-            **kwargs
-        )
+        print("this API was removed. use download_library_v2")
 
     def download_library_v2(
         self, folder="", run_async=True, platform=None, renderer=None, *args, **kwargs
@@ -783,111 +736,6 @@ class KnowledgePack(VisualizeMixin):
                 renderer.render(err_msg)
             return err_msg, False
 
-    def _download(
-        self,
-        folder,
-        bin_or_lib,
-        run_async=False,
-        platform=None,
-        renderer=None,
-        *args,
-        **kwargs
-    ):
-        _path = r"{0}".format(folder)
-        url = "project/{0}/sandbox/{1}/knowledgepack/{2}/generate_{3}/".format(
-            self._project_uuid, self._sandbox_uuid, self.uuid, bin_or_lib
-        )
-        # config = self._sandbox.device_config.copy() # get a regular dictionary
-
-        if platform is not None and type(platform) is PlatformDescription:
-            kwargs["config"] = {"target_platform": platform.id}
-        elif platform is not None and type(platform) is not PlatformDescription:
-            err_msg = "Platform not properly specified. Specify via client.platforms()"
-            if renderer:
-                renderer.render(err_msg)
-            return err_msg, False
-
-        config = kwargs.pop("config", None)
-        if config:
-            if "kb_description" in config and isinstance(
-                config["kb_description"], dict
-            ):
-                config["kb_description"] = json.dumps(config["kb_description"])
-            for key in kwargs:
-                if key in [
-                    "debug",
-                    "test_data",
-                    "application",
-                    "sample_rate",
-                    "output_options",
-                    "debug_level",
-                    "profile",
-                    "profile_iterations",
-                ]:
-                    config.update({key: kwargs[key]})
-                if key == "kb_description":
-                    config.update({key: json.dumps(kwargs[key])})
-        else:
-            config = self.get_sandbox_device_config()
-
-        print("Generating {} with configuration".format(bin_or_lib))
-        for key in config:
-            print("{} : {}".format(key, config[key]))
-
-        if config.get("target_platform", None) is None:
-            raise KnowledgePackException("Target platform must be specified.")
-        config["asynchronous"] = run_async
-        response = self._connection.request("post", url, data=config)
-        response_data, err = utility.check_server_response(
-            response, is_octet=True, renderer=renderer
-        )
-
-        msg = "Generating Knowledge Pack"
-        count = 0
-        while True:
-            response = self._connection.request("get", url)
-            response_data, err = utility.check_server_response(
-                response, is_octet=True, renderer=renderer
-            )
-            if (
-                err
-                or "content-disposition" in response_data.headers
-                or response_data.json().get("task_state") in ("FAILURE",)
-            ):
-                break
-            sys.stdout.write(".")
-            if renderer:
-                msg += " ."
-                renderer.render(msg)
-            sleep(5)
-        if "content-disposition" in response_data.headers:
-            if kwargs.get("save_as"):
-                filename = kwargs.get("save_as", None)
-            else:
-                filename = re.findall(
-                    'filename="([^"]+)"', response_data.headers["content-disposition"]
-                )[0]
-            if filename is None:
-                filename = re.findall(
-                    'filename="([^"]+)"', response_data.headers["content-disposition"]
-                )[0]
-            file_path = os.path.join(_path, filename)
-            with open(file_path, "wb") as f:
-                for d in response_data.iter_content(2048):
-                    f.write(d)
-
-            output_path = os.path.join(os.path.abspath("."), file_path)
-            if renderer:
-                renderer.render("KnowledgePack saved to\n{0}".format(output_path))
-
-            return output_path, True
-        else:
-            err_msg = response_data.json().get("task_result")
-            print(err_msg)
-            if renderer:
-                renderer.render(err_msg)
-            return err_msg, False
-
     def get_build_log(self, renderer=None, save_as=None):
         url = "knowledgepack/{0}/build-logs/".format(self.uuid)
 
