@@ -1,14 +1,16 @@
 from __future__ import print_function
-import os
-import sys
+
+import datetime
 import inspect
 import json
+import os
+import sys
+from copy import deepcopy
 from logging import debug
+from numbers import Number
+
 import pandas as pd
 from pandas import DataFrame
-from copy import deepcopy
-from numbers import Number
-import datetime
 from sensiml.render import BaseRenderer
 
 try:
@@ -16,16 +18,15 @@ try:
 except ImportError:
     from urllib import urlencode
 
-
 import sensiml.base.utility as utility
-from sensiml.datamanager.pipeline import PipelineStep, PipelineError
-from sensiml.datamanager.knowledgepack import KnowledgePack
-from sensiml.method_calls.functioncalls import FunctionCalls
-from sensiml.method_calls.selectorcallset import SelectorCallSet
-from sensiml.method_calls.generatorcallset import GeneratorCallSet
-from sensiml.method_calls.trainandvalidationcall import TrainAndValidationCall
-from sensiml.datamanager.modelresults import ModelResultSet
 from sensiml.datamanager.deviceconfig import DeviceConfig
+from sensiml.datamanager.knowledgepack import KnowledgePack
+from sensiml.datamanager.modelresults import ModelResultSet
+from sensiml.datamanager.pipeline import PipelineError, PipelineStep
+from sensiml.method_calls.functioncalls import FunctionCalls
+from sensiml.method_calls.generatorcallset import GeneratorCallSet
+from sensiml.method_calls.selectorcallset import SelectorCallSet
+from sensiml.method_calls.trainandvalidationcall import TrainAndValidationCall
 
 
 class SandboxPipeline:
@@ -566,7 +567,7 @@ class Sandbox(object):
 
         Returns:
             (dict): dictionary containing metrics result set from server"""
-        url = "get_metrics_set/"
+        url = "get-metrics-set/"
         response = self._connection.request("get", url, data)
         data, err = utility.check_server_response(response)
         if err is False:
