@@ -1,9 +1,10 @@
-import os
 import json
+import os
+from typing import Dict, List, Optional, Tuple, Type
+
+import matplotlib.pyplot as plt
 from pandas.core.frame import DataFrame
 from sensiml.dclproj.utils import mfcc
-import matplotlib.pyplot as plt
-from typing import List, Optional, Dict, Tuple, Type
 
 
 class DataSegment(object):
@@ -51,10 +52,8 @@ class DataSegment(object):
             channel (str): the channel/column of sensor data to use
             fft_length (int, optional): The size of the FTT length to use when computing the spectrogram. Defaults to 512.
             figsize (Tuple, optional): the size of the figure that will be created. Defaults to (30, 4).
-
-        Returns:
-            _type_: None
         """
+
         fig, axis = plt.subplots(figsize=figsize)
 
         data = axis.specgram(self._data[channel], NFFT=fft_length, **kwargs)
@@ -62,15 +61,12 @@ class DataSegment(object):
     def plot_mfcc(
         self, channel: str, sample_freq: int = 16000, figsize: Tuple = (30, 4)
     ):
-        """Plots the mfcc spectrogram for the signal.
+        """Plots the MFCC spectrogram for the signal.
 
         Args:
             channel (str): the channel/column of sensor data to use
             sample_freq (int, optional): The frequency of the sample data. Defaults to 1600.
             figsize (Tuple, optional): the size of the figure that will be created. Defaults to (30, 4).
-
-        Returns:
-            _type_: None
         """
         fig, axis = plt.subplots(figsize=figsize)
 
@@ -82,15 +78,12 @@ class DataSegment(object):
     def plot_frequency(
         self, channel: str, sample_freq: int = 16000, figsize: Tuple = (30, 8), **kwargs
     ):
-        """Plots the signal data, the spectrogram and the mfcc spectrogram.
+        """Plots the signal data, the spectrogram and the MFCC spectrogram.
 
         Args:
             channel (str): the channel/column of sensor data to use
             sample_freq (int, optional): The frequency of the sample data. Defaults to 1600.
             figsize (Tuple, optional): the size of the figure that will be created. Defaults to (30, 4).
-
-        Returns:
-            _type_: None
         """
 
         fig, axes = plt.subplots(nrows=3, ncols=1, figsize=figsize)
@@ -169,15 +162,17 @@ class DataSegment(object):
 
 
 class DataSegments(dict):
+    """DataSegments is a dictionary of DataSegment objects with additional APIs"""
+
     def plot(self, **kwargs):
-        import matplotlib as plt
 
         plt.rcParams.update({"figure.max_open_warning": 0})
         for _, segment in self.items():
             segment.plot(**kwargs)
 
-    def to_dataframe(self):
+    def to_dataframe(self) -> DataFrame:
         """Returns a dataframe representation of the segment information."""
+
         M = []
         for _, segment in self.items():
             M.append(segment.metadata)
@@ -191,7 +186,13 @@ class DataSegments(dict):
             by=["session", "capture", "capture_sample_sequence_start"]
         ).reset_index(drop=True)
 
-    def to_dict(self, orient: str = "records"):
+    def to_dict(self, orient: str = "records") -> Dict:
+        """Returns a dictionary representation of the DataSegments object
+
+        Args:
+            orient (str): defaults to records
+        """
+
         return self.to_dataframe().to_dict(orient=orient)
 
     def export(self, folder: str = "segment_export"):
@@ -201,6 +202,7 @@ class DataSegments(dict):
         Args:
             folder (str, optional): The folder to export to. Defaults to "segment_export".
         """
+
         if not os.path.exists(folder):
             os.mkdir(folder)
 
@@ -221,7 +223,7 @@ class DataSegments(dict):
             session (Optional[str], optional): The name of a session to use when creating the DCLI file. if None the session from the DataSegment objects are used.. Defaults to None.
 
         Returns:
-            List: A dcli object
+            List: DCLI formatted segments
         """
 
         def get_capture_index(dcli_capture, file_name):
@@ -281,13 +283,11 @@ class DataSegments(dict):
 
     def to_audacity(self, rate: int = 16000) -> List:
         """Creates multiple files with the naming convention file_{capture_name}session{session_name}.txt.
+
         These can be imported into Audacity directly going to File->Import->Labels
 
         Args:
-          rate (int): Audacity uses the actual time and note number of samples. Set the rate to the sample rate for the captured date. Default is 16000.
-
-        Returns:
-            None
+            rate (int): Audacity uses the actual time and note number of samples. Set the rate to the sample rate for the captured date. Default is 16000.
         """
 
         dcli = self.to_dcli()
@@ -314,6 +314,7 @@ class DataSegments(dict):
     @property
     def label_values(self) -> List:
         """List all the labels in the DataSegments object"""
+
         label_values = set()
         for _, segment in self.items():
             label_values.add(segment.label_value)
@@ -420,7 +421,6 @@ class DataSegments(dict):
 
         Returns:
             DataFrame: A DataFrame consisting of the segments not filtered
-
         """
 
         return join_segments(self)
@@ -435,6 +435,7 @@ class DataSegments(dict):
         Returns:
             DataSegments: A DataSegments object consisting of the merged segments
         """
+
         joined_segments = join_segments(self)
 
         return segment_list_to_datasegments(dcl, joined_segments)
@@ -472,19 +473,16 @@ def to_datasegments(data, metdata_columns: list, label_column: str):
 
 
 def segment_list_to_datasegments(dcl, labels: DataFrame, session: str = ""):
-    """_summary_
+    """Converts a DataFrame of segments into a DataSegments object
 
     Args:
         dcl (DCLProject): A DCLProject object that is connected to the DCLI file
         labels (DataFrame): A dataframe containing the segment information
         session (str, optional): The session to set the segments too. Defaults to "".
 
-    Raises:
-        Exception: _description_
-
     Returns:
-        _type_: _description_
-    """ """Converts a dataframe into a data segments object"""
+        DataSegments
+    """
 
     if isinstance(labels, DataFrame):
 
@@ -544,8 +542,7 @@ def segment_list_to_datasegments(dcl, labels: DataFrame, session: str = ""):
 def audacity_to_datasegments(
     dcl, capture_name, file_path: str, session: str = "", rate: int = 16000
 ):
-    """
-    Converts labels exported from Audacity into a datasegment object.
+    """Converts labels exported from Audacity into a datasegment object.
 
     Args:
         dcl (DCLProject): A DCLProject object that is connected to the DCLI file
@@ -648,7 +645,7 @@ def merge_segments(segments: DataFrame, delta: int = 10) -> DataFrame:
         delta (int, optional): The distance between two nonoverlapping segments where they will still be merged. Defaults to 10.
 
     Returns:
-        DataFrame: DataFrame continaing the merged segments
+        DataFrame: DataFrame containing the merged segments
     """
 
     if isinstance(segments, DataFrame):
@@ -816,7 +813,7 @@ def remove_overlap(segments) -> DataFrame:
 
 
 def join_segments(segments, delta: Optional[int] = None) -> DataFrame:
-    """If there are any gaps between two segments, this will bring them together so their is no unlabeled data."""
+    """If there are any gaps between two segments, this will bring them together so there are no unlabeled regions of data."""
 
     if isinstance(segments, DataFrame):
         seg_groups = segments.groupby(["session", "capture"])
