@@ -1,17 +1,17 @@
-import sqlite3
 import os
-import pandas as pd
-import numpy as np
-from pandas.core.frame import DataFrame
-from sensiml.dclproj.datasegments import DataSegments, DataSegment
+import sqlite3
 import uuid
-from collections import OrderedDict
-from matplotlib.lines import Line2D
-import matplotlib.pyplot as plt
-from typing import List, Optional, Dict, Tuple
 import wave
+from collections import OrderedDict
+from typing import Dict, List, Optional, Tuple
 
-from sensiml.dclproj.utils import plot_segments_labels, mfcc
+import matplotlib.pyplot as plt
+import numpy as np
+import pandas as pd
+from matplotlib.lines import Line2D
+from pandas.core.frame import DataFrame
+from sensiml.dclproj.datasegments import DataSegment, DataSegments
+from sensiml.dclproj.utils import mfcc, plot_segments_labels
 
 
 class DCLProject:
@@ -48,8 +48,8 @@ class DCLProject:
         self._tables = [x[0] for x in cursorObj.fetchall()]
 
     def create_connection(self, db_file: str) -> None:
-        """create a database connection to the SQLite database
-            specified by db_file
+        """create a database connection to the SQLite database specified by db_file
+
         :param db_file: database file
         :return: None
         """
@@ -178,7 +178,7 @@ class DCLProject:
         return self._execute_query(query_select + query_join + query_where, header)
 
     def _list_captures_metadata(self) -> DataFrame:
-        "returns a dataframe containing the capture name and the associated metadata"
+        """returns a dataframe containing the capture name and the associated metadata"""
 
         fields = ["uuid"]
 
@@ -208,7 +208,7 @@ class DCLProject:
 
         Returns:
             DataFrame: DataFrame containing the capture information
-        """ ""
+        """
 
         fields = [
             "uuid",
@@ -258,7 +258,7 @@ class DCLProject:
             sessions (Optional[List], optional): A list of sessions to return segments for. Defaults to None.
 
         Returns:
-            DataFrame: _description_
+            DataFrame:
         """
 
         if captures is not None and isinstance(captures, str):
@@ -336,7 +336,6 @@ class DCLProject:
         Args:
             capture_name (str): name of capture
             session (str):  name of session where the labels are
-
         """
         if captures is not None and isinstance(captures, str):
             captures = [captures]
@@ -383,7 +382,6 @@ class DCLProject:
 
         Args:
             capture_name (str): name of capture
-
         """
 
         # TODO: read wave file if file is .wav
@@ -416,7 +414,6 @@ class DCLProject:
 
         Args:
             capture_names (List[str]): name of captures to return, if None returns all captures
-
         """
         if capture_names is None:
             capture_names = os.listdir(self.data_dir)
@@ -446,37 +443,28 @@ class DCLProject:
             transforms: additional fucntions to apply prior to plotting the data
 
 
-        example of a single transform::
+        Examples:
+            >>> def sum_columns(x):
+            >>>     return x[['Column1', 'Column2']].sum()
 
-        ```
-            def sum_columns(x):
-                return x[['Column1', 'Column2']].sum()
+            >>> func = {'name':'sum','func':sum_columns, 'type':'transform'}
 
-            func = {'name':'sum','func':sum_columns, 'type':'transform'}
+            >>> dcl.plot_segment_labels(captures, session_name, columns=['sum], transforms=[func])
 
-            dcl.plot_segment_labels(captures, session_name, columns=['sum], transforms=[func])
-        ```
+            >>> # example of multiple transforms executed in order
 
-        example of multiple transforms
-        transforms will be executed in order
+            >>> def sum_columns(x):
+            >>>     return x[['Column1', 'Column2']].sum()
 
-        ```
-
-            def sum_columns(x):
-                return x[['Column1', 'Column2']].sum()
-
-            def remove_offset(x):
-                x['Column1']-=100
-                x['Column2']-=200
-                return x
-
-            func2 = {'name':'filter','func':remove_offset, "type":'filter', "columns":['Column1', 'Column2']}
-            func1 = {'name':'sum','func':sum_columns, "type":'transform'}
-
-
-            dcl.plot_segment_labels(captures, session_name, columns=['Column1', 'Column2', 'sum'], transforms=[func1, func2])
+            >>> def remove_offset(x):
+            >>>    x['Column1']-=100
+            >>>    x['Column2']-=200
+            >>>    return x
 
+            >>> func2 = {'name':'filter','func':remove_offset, "type":'filter', "columns":['Column1', 'Column2']}
+            >>> func1 = {'name':'sum','func':sum_columns, "type":'transform'}
 
+            >>> dcl.plot_segment_labels(captures, session_name, columns=['Column1', 'Column2', 'sum'], transforms=[func1, func2])
         """
 
         sessions = self.list_sessions()
