@@ -6,14 +6,23 @@ class VisualizeMixin:
         """plots the loss and validation accuracy during training for a model"""
         if self.training_metrics:
             fig = plt.figure(figsize=figsize)
-            num_iterations = len(self.training_metrics["validation_accuracy"])
-            plt.plot(self.training_metrics["train_accuracy"], label="training")
-            plt.plot(self.training_metrics["validation_accuracy"], label="validation")
+            num_iterations = len(self.training_metrics["loss"])
+            plt.plot(self.training_metrics["accuracy"], label="training")
+            plt.plot(self.training_metrics["val_accuracy"], label="validation")
             plt.xlabel("epochs")
-            plt.ylabel("accuracy")
+            plt.ylabel("Accuracy")
             plt.xlim(0, num_iterations)
             plt.ylim(0, 1)
             plt.legend(loc="best")
             plt.show()
+            fig = plt.figure(figsize=figsize)
+            num_iterations = len(self.training_metrics["loss"])
+            plt.plot(self.training_metrics["loss"], label="training")
+            plt.plot(self.training_metrics["val_loss"], label="validation")
+            plt.xlabel("epochs")
+            plt.ylabel("Loss")
+            plt.xlim(0, num_iterations)
+            plt.legend(loc="best")
+            plt.show()
         else:
             print("No training metrics for this model")
