@@ -11,7 +11,7 @@ import io
 class Visualize(object):
     def __init__(self, feature_vector=None, model=None, label=None):
         """
-        model: model result or knowledpack
+        model: model result or knowledgepack
         feature_vector (Dataframe): feature set that is results of generator_set or feature_selector
         label (String), name of class
         """
@@ -23,7 +23,7 @@ class Visualize(object):
         self.label = label
         if self.label is None:
             print(
-                "Label column is not specified for this knowledpack, specify as label=XXX"
+                "Label column is not specified for this knowledgepack, specify as label=XXX"
             )
         self.feature_vector = feature_vector
 
@@ -188,7 +188,7 @@ class Visualize(object):
             vector_labels (List): which features will be displayed  [ f1, f2, f3, ..., 'all', [] ], ['all'] display all features, [] does not display any features
             vector_alpha = 0.3, level of vector transparency
             neuron_alpha = 0.1, level of neuron transparency
-            norm(int): takes from knowledpack, to overide 0=L1, 1=LSUP
+            norm(int): takes from knowledgepack, to overide 0=L1, 1=LSUP
 
         Returns: None
 
